==> _private_core_network-1.3.11.tar.gz: lib/network_resources/auth/repo.dart <==
import 'dart:collection';

import 'package:_private_core/_private_core.dart';
import 'package:_private_core_network/network_resources/resources.dart';
import 'package:dio/dio.dart';
import 'app_api.dart';
import 'models/auth_industry.dart';

class AuthXRepo {
  AuthXRepo._();

  static AuthXRepo? _instance;

  factory AuthXRepo([MyAppApi? api]) {
    _instance ??= AuthXRepo._();
    _instance!._api = api ?? MyAppApiImp();
    return _instance!;
  }

  late MyAppApi _api;

  Map<String, dynamic> _mapParms([Map? value]) {
    Map<String, dynamic> params = {};
    if (value != null && value.isNotEmpty) params.addAll(HashMap.from(value));
    params
      ..removeWhere((key, value) => value == null)
      ..addAll({
        'platformId': valuePlatformByConfig(),
        'languageCode': appPrefs.languageCode,
      });
    return params;
  }

  Future<NetworkResponse> resetPasswordByEmail(params) async {
    return await _api.resetPasswordByEmail(_mapParms(params));
  }

  Future<ConfirmOtp?> confirmResetProPasswordCode(params) async {
    NetworkResponse response =
        await _api.confirmResetProPasswordCode(_mapParms(params));
    return response.data;
  }

  Future<bool> updateNewProPasswordByToken(params) async {
    NetworkResponse response =
        await _api.updateNewProPasswordByToken(_mapParms(params));
    return response.data;
  }

  Future<ConfirmOtp?> confirmResetUserPasswordCode(params) async {
    NetworkResponse response =
        await _api.confirmResetUserPasswordCode(_mapParms(params));
    return response.data;
  }

  Future<bool> updateNewUserPasswordByToken(params) async {
    NetworkResponse response =
        await _api.updateNewUserPasswordByToken(_mapParms(params));
    return response.data;
  }

  Future<String?> setThumbnailForPro(image, filePath,
      [ProgressCallback? callback]) async {
    NetworkResponse response =
        await _api.setThumbnailForPro(image, filePath, callback);
    return response.data;
  }

  Future<String?> setThumbnailForUser(image, filePath,
      [ProgressCallback? callback]) async {
    NetworkResponse response =
        await _api.setThumbnailForUser(image, filePath, callback);
    return response.data;
  }

  Future<ProInfo?> getProInfo([params]) async {
    NetworkResponse response = await _api.getProInfo(_mapParms(params));
    return response.data;
  }

  Future<UserModel?> getUserInfo([params]) async {
    NetworkResponse response = await _api.getUserInfo(_mapParms(params));
    return response.data;
  }

  Future<List<AuthIndustry>> getServiceCatForIndustry([params]) async {
    NetworkResponse response =
        await _api.getServiceCatForIndustry(_mapParms(params));
    return response.data ?? [];
  }
}

==> _private_core_network-1.3.31.tar.gz: lib/network_resources/auth/repo.dart <==
import 'package:_private_core_network/network_resources/resources.dart';
import 'package:dio/dio.dart';
import 'app_api.dart';
import 'models/auth_industry.dart';

class AuthXRepo {
  AuthXRepo._();

  static AuthXRepo? _instance;

  factory AuthXRepo([MyAppApi? api]) {
    _instance ??= AuthXRepo._();
    _instance!._api = api ?? MyAppApiImp();
    return _instance!;
  }

  late MyAppApi _api;

  Future<NetworkResponse> resetPasswordByEmail(params) async {
    return await _api.resetPasswordByEmail(params);
  }

  Future<ConfirmOtp?> confirmResetProPasswordCode(params) async {
    NetworkResponse response = await _api.confirmResetProPasswordCode(params);
    return response.data;
  }

  Future<bool> updateNewProPasswordByToken(params) async {
    NetworkResponse response = await _api.updateNewProPasswordByToken(params);
    return response.data;
  }

  Future<ConfirmOtp?> confirmResetUserPasswordCode(params) async {
    NetworkResponse response = await _api.confirmResetUserPasswordCode(params);
    return response.data;
  }

  Future<bool> updateNewUserPasswordByToken(params) async {
    NetworkResponse response = await _api.updateNewUserPasswordByToken(params);
    return response.data;
  }

  Future<String?> setThumbnailForPro(image, filePath,
      [ProgressCallback? callback]) async {
    NetworkResponse response =
        await _api.setThumbnailForPro(image, filePath, callback);
    return response.data;
  }

  Future<String?> setThumbnailForUser(image, filePath,
      [ProgressCallback? callback]) async {
    NetworkResponse response =
        await _api.setThumbnailForUser(image, filePath, callback);
    return response.data;
  }

  Future<ProInfo?> getProInfo([params]) async {
    NetworkResponse response = await _api.getProInfo(params);
    return response.data;
  }

  Future<UserModel?> getUserInfo([params]) async {
    NetworkResponse response = await _api.getUserInfo(params);
    return response.data;
  }

  Future<List<AuthIndustry>> getServiceCatForIndustry([params]) async {
    NetworkResponse response = await _api.getServiceCatForIndustry(params);
    return response.data ?? [];
  }

  Future loginTerminal({required params}) async {
    return await _api.loginTerminal(params);
  }

  Future<NetworkResponse> loginUserOrProByUsername(params) async {
    return await _api.loginUserOrProByUsername(params);
  }
}
